@@ -3,17 +3,6 @@ import importlib
 
 from lesscode.db.base_connection_pool import BaseConnectionPool
 
-pymysql = None
-aiomysql = None
-try:
-    pymysql = importlib.import_module("pymysql")
-except ImportError as e:
-    raise Exception(f"pymysql is not exist,run:pip install pymysql==0.9.3")
-
-try:
-    aiomysql = importlib.import_module("aiomysql")
-except ImportError as e:
-    raise Exception(f"pymysql is not exist,run:pip install aiomysql==0.0.22")
 pooled_db = None
 try:
     pooled_db = importlib.import_module("dbutils.pooled_db")
@@ -31,6 +20,10 @@ class MysqlPool(BaseConnectionPool):
         创建mysql 异步连接池
         :return:
         """
+        try:
+            aiomysql = importlib.import_module("aiomysql")
+        except ImportError as e:
+            raise Exception(f"pymysql is not exist,run:pip install aiomysql==0.0.22")
         if self.conn_info.async_enable:
             pool = await aiomysql.create_pool(host=self.conn_info.host, port=self.conn_info.port,
                                               user=self.conn_info.user,
@@ -45,6 +38,10 @@ class MysqlPool(BaseConnectionPool):
             raise NotImplementedError
 
     def sync_create_pool(self):
+        try:
+            pymysql = importlib.import_module("pymysql")
+        except ImportError as e:
+            raise Exception(f"pymysql is not exist,run:pip install pymysql==0.9.3")
         pool = pooled_db.PooledDB(creator=pymysql, host=self.conn_info.host, port=self.conn_info.port,
                                   user=self.conn_info.user,
                                   passwd=self.conn_info.password, db=self.conn_info.db_name,
