@@ -1,10 +1,6 @@
 # -*- coding: utf-8 -*-
-# author:chao.yy
-# email:yuyc@ishangqi.com
-# date:2021/11/26 3:56 下午
-# Copyright (C) 2021 The lesscode Team
-import neo4j.data
-import neo4j.graph
+import importlib
+
 from tornado.options import options
 
 import logging
@@ -13,6 +9,13 @@ import traceback
 from lesscode.db.page import Page
 from lesscode.utils.encryption_algorithm import AES
 
+try:
+    neo4j = importlib.import_module("neo4j")
+    neo4j_data = importlib.import_module("neo4j.data")
+    neo4j_graph = importlib.import_module("neo4j.graph")
+except ImportError as e:
+    raise Exception(f"neo4j is not exist,run:pip install neo4j==5.0.0")
+
 
 class Neo4jHelper:
     """
@@ -1026,49 +1029,49 @@ def dict_str(data: dict):
     return string
 
 
-def node2dict(node: neo4j.graph.Node):
+def node2dict(node: neo4j_graph.Node):
     return {"id": node.id, "labels": list(node.labels), "properties": node._properties}
 
 
-def relationship2dict(relationship: neo4j.graph.Relationship):
+def relationship2dict(relationship: neo4j_graph.Relationship):
     return {"start_node": node2dict(relationship.start_node), "end_node": node2dict(relationship.end_node),
             "id": relationship.id,
             "type": relationship.type, "properties": relationship._properties}
 
 
-def path2dict(path: neo4j.graph.Path):
+def path2dict(path: neo4j_graph.Path):
     return {"start_node": node2dict(path.start_node), "end_node": node2dict(path.end_node),
             "nodes": [node2dict(n) for n in path.nodes],
             "relationships": [relationship2dict(r) for r in path.relationships]}
 
 
-def parse_record(record: neo4j.data.Record, flag=True):
+def parse_record(record: neo4j_data.Record, flag=True):
     _record = {"node": [], "relationship": [], "path": [], "other": []}
-    if isinstance(record, neo4j.data.Record):
+    if isinstance(record, neo4j_data.Record):
         for rd in record:
-            if isinstance(rd, neo4j.graph.Node):
+            if isinstance(rd, neo4j_graph.Node):
                 _record["node"].append(node2dict(rd))
-            elif issubclass(rd.__class__, neo4j.graph.Node):
+            elif issubclass(rd.__class__, neo4j_graph.Node):
                 _record["node"].append(node2dict(rd))
-            elif isinstance(rd, neo4j.graph.Relationship):
+            elif isinstance(rd, neo4j_graph.Relationship):
                 _record["relationship"].append(relationship2dict(rd))
-            elif issubclass(rd.__class__, neo4j.graph.Relationship):
+            elif issubclass(rd.__class__, neo4j_graph.Relationship):
                 _record["relationship"].append(relationship2dict(rd))
             elif isinstance(rd, list) or isinstance(rd, tuple):
                 for x in rd:
-                    if isinstance(x, neo4j.graph.Node):
+                    if isinstance(x, neo4j_graph.Node):
                         _record["node"].append(node2dict(x))
-                    elif issubclass(x.__class__, neo4j.graph.Node):
+                    elif issubclass(x.__class__, neo4j_graph.Node):
                         _record["node"].append(node2dict(x))
-                    elif isinstance(x, neo4j.graph.Relationship):
+                    elif isinstance(x, neo4j_graph.Relationship):
                         _record["relationship"].append(relationship2dict(x))
-                    elif issubclass(x.__class__, neo4j.graph.Relationship):
+                    elif issubclass(x.__class__, neo4j_graph.Relationship):
                         _record["relationship"].append(relationship2dict(x))
-                    elif isinstance(x, neo4j.graph.Path):
+                    elif isinstance(x, neo4j_graph.Path):
                         _record["path"].append(path2dict(x))
                     else:
                         _record["other"].append(x)
-            elif isinstance(rd, neo4j.graph.Path):
+            elif isinstance(rd, neo4j_graph.Path):
                 _record["path"].append(path2dict(rd))
             else:
                 _record["other"].append(rd)
