@@ -3,18 +3,6 @@ import importlib
 
 from lesscode.db.base_connection_pool import BaseConnectionPool
 
-redis = None
-aioredis = None
-try:
-    redis = importlib.import_module("redis")
-except ImportError as e:
-    raise Exception(f"redis is not exist,run:pip install redis==4.1.4")
-
-try:
-    aioredis = importlib.import_module("aioredis")
-except ImportError as e:
-    raise Exception(f"aioredis is not exist,run:pip install aioredis==2.0.1")
-
 
 class RedisPool(BaseConnectionPool):
     """
@@ -26,6 +14,10 @@ class RedisPool(BaseConnectionPool):
         创建mysql 异步连接池
         :return:
         """
+        try:
+            aioredis = importlib.import_module("aioredis")
+        except ImportError as e:
+            raise Exception(f"aioredis is not exist,run:pip install aioredis==2.0.1")
         if self.conn_info.async_enable:
             pool = aioredis.ConnectionPool.from_url(f"redis://{self.conn_info.host}", port=self.conn_info.port,
                                                     password=self.conn_info.password,
@@ -35,6 +27,10 @@ class RedisPool(BaseConnectionPool):
             raise NotImplementedError
 
     def sync_create_pool(self):
+        try:
+            redis = importlib.import_module("redis")
+        except ImportError as e:
+            raise Exception(f"redis is not exist,run:pip install redis==4.1.4")
         pool = redis.ConnectionPool.from_url(f"redis://{self.conn_info.host}", port=self.conn_info.port,
                                              password=self.conn_info.password,
                                              db=self.conn_info.db_name, encoding="utf-8", decode_responses=True)
